"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import share as shared_share
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import date
from enum import Enum
from marshmallow import fields
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSharesRequestBodyAvailabilityRuleRulesIntervals:
    
    from_: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from'), 'exclude': lambda f: f is None }})
    r"""Format: `\\"hh:mm\\"`"""  
    to: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('to'), 'exclude': lambda f: f is None }})
    r"""Format: `\\"hh:mm\\"`"""  
    
class PostSharesRequestBodyAvailabilityRuleRulesTypeEnum(str, Enum):
    WDAY = 'wday'
    DATE = 'date'

class PostSharesRequestBodyAvailabilityRuleRulesWdayEnum(str, Enum):
    r"""is required when `type` is 'wday'"""
    SUNDAY = 'sunday'
    MONDAY = 'monday'
    TUESDAY = 'tuesday'
    WEDNESDAY = 'wednesday'
    THURSDAY = 'thursday'
    FRIDAY = 'friday'
    SATURDAY = 'saturday'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSharesRequestBodyAvailabilityRuleRules:
    
    date_: Optional[date] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('date'), 'encoder': utils.dateisoformat(True), 'decoder': utils.datefromisoformat, 'mm_field': fields.DateTime(format='iso'), 'exclude': lambda f: f is None }})
    r"""is required when `type` is 'date'
    Format: `YYYY-MM-DD`
    """  
    intervals: Optional[list[PostSharesRequestBodyAvailabilityRuleRulesIntervals]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('intervals'), 'exclude': lambda f: f is None }})  
    type: Optional[PostSharesRequestBodyAvailabilityRuleRulesTypeEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type'), 'exclude': lambda f: f is None }})  
    wday: Optional[PostSharesRequestBodyAvailabilityRuleRulesWdayEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('wday'), 'exclude': lambda f: f is None }})
    r"""is required when `type` is 'wday'"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSharesRequestBodyAvailabilityRule:
    
    rules: Optional[list[PostSharesRequestBodyAvailabilityRuleRules]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('rules'), 'exclude': lambda f: f is None }})
    r"""are required when an availability rule is provided"""  
    timezone: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('timezone'), 'exclude': lambda f: f is None }})
    r"""is required when an availability rule is provided"""  
    
class PostSharesRequestBodyLocationConfigurationsKindEnum(str, Enum):
    PHYSICAL = 'physical'
    ASK_INVITEE = 'ask_invitee'
    CUSTOM = 'custom'
    OUTBOUND_CALL = 'outbound_call'
    INBOUND_CALL = 'inbound_call'
    GOOGLE_CONFERENCE = 'google_conference'
    GOTOMEETING_CONFERENCE = 'gotomeeting_conference'
    MICROSOFT_TEAMS_CONFERENCE = 'microsoft_teams_conference'
    WEBEX_CONFERENCE = 'webex_conference'
    ZOOM_CONFERENCE = 'zoom_conference'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSharesRequestBodyLocationConfigurations:
    
    additional_info: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('additional_info'), 'exclude': lambda f: f is None }})
    r"""is only supported when `kind` is 'physical' or 'inbound_call'"""  
    kind: Optional[PostSharesRequestBodyLocationConfigurationsKindEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('kind'), 'exclude': lambda f: f is None }})  
    location: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location'), 'exclude': lambda f: f is None }})
    r"""is only supported when `kind` is 'physical', 'custom' or 'ask_invitee'"""  
    phone_number: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('phone_number'), 'exclude': lambda f: f is None }})
    r"""is required when `kind` is 'inbound_call'"""  
    position: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('position'), 'exclude': lambda f: f is None }})  
    
class PostSharesRequestBodyPeriodTypeEnum(str, Enum):
    AVAILABLE_MOVING = 'available_moving'
    MOVING = 'moving'
    FIXED = 'fixed'
    UNLIMITED = 'unlimited'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSharesRequestBody:
    
    event_type: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('event_type') }})  
    availability_rule: Optional[PostSharesRequestBodyAvailabilityRule] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('availability_rule'), 'exclude': lambda f: f is None }})  
    duration: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('duration'), 'exclude': lambda f: f is None }})  
    end_date: Optional[date] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('end_date'), 'encoder': utils.dateisoformat(True), 'decoder': utils.datefromisoformat, 'mm_field': fields.DateTime(format='iso'), 'exclude': lambda f: f is None }})
    r"""is required when `period_type` is 'fixed'
    Format: `YYYY-MM-DD`
    """  
    hide_location: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('hide_location'), 'exclude': lambda f: f is None }})
    r"""determines if a location is hidden until invitee books a spot, only respected when there is a single custom location configured"""  
    location_configurations: Optional[list[PostSharesRequestBodyLocationConfigurations]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location_configurations'), 'exclude': lambda f: f is None }})  
    max_booking_time: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('max_booking_time'), 'exclude': lambda f: f is None }})
    r"""is required when `period_type` is 'moving' or 'available_moving'"""  
    name: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name'), 'exclude': lambda f: f is None }})  
    period_type: Optional[PostSharesRequestBodyPeriodTypeEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('period_type'), 'exclude': lambda f: f is None }})  
    start_date: Optional[date] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('start_date'), 'encoder': utils.dateisoformat(True), 'decoder': utils.datefromisoformat, 'mm_field': fields.DateTime(format='iso'), 'exclude': lambda f: f is None }})
    r"""is required when `period_type` is 'fixed'
    Format: `YYYY-MM-DD`
    """  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSharesErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSharesErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[PostSharesErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostShares201ApplicationJSON:
    r"""Created"""
    
    resource: shared_share.Share = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('resource') }})  
    

@dataclasses.dataclass
class PostSharesResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[PostSharesErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    post_shares_201_application_json_object: Optional[PostShares201ApplicationJSON] = dataclasses.field(default=None)
    r"""Created"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from ..shared import eventtypecustomquestion as shared_eventtypecustomquestion
from ..shared import profile as shared_profile
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields

class EventTypeBookingMethodEnum(str, Enum):
    r"""Indicates if the event type is for a poll or an instant booking"""
    INSTANT = 'instant'
    POLL = 'poll'

class EventTypeKindEnum(str, Enum):
    r"""Indicates if the event type is \\"solo\\" (belongs to an individual user) or \\"group\\" """
    SOLO = 'solo'
    GROUP = 'group'

class EventTypeKindDescriptionEnum(str, Enum):
    r"""A formatted description of the kind of event type."""
    COLLECTIVE = 'Collective'
    GROUP = 'Group'
    ONE_ON_ONE = 'One-on-One'
    ROUND_ROBIN = 'Round Robin'

class EventTypePoolingTypeEnum(str, Enum):
    r"""Indicates if the event type is \\"round robin\\" (alternates between hosts) or \\"collective\\" (invitees pick a time when all participants are available) or \\"null\\" (the event type doesn’t consider the availability of a group participants)"""
    ROUND_ROBIN = 'round_robin'
    COLLECTIVE = 'collective'
    NULL = 'null'

class EventTypeTypeEnum(str, Enum):
    r"""Indicates if the event type is \\"AdhocEventType\\" (ad hoc event) or \\"StandardEventType\\" (standard event type)"""
    STANDARD_EVENT_TYPE = 'StandardEventType'
    ADHOC_EVENT_TYPE = 'AdhocEventType'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class EventType:
    r"""A configuration for an Event"""
    
    active: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('active') }})
    r"""Indicates if the event is active or not."""  
    admin_managed: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('admin_managed') }})
    r"""Indicates if this event type is managed by an organization admin"""  
    booking_method: EventTypeBookingMethodEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('booking_method') }})
    r"""Indicates if the event type is for a poll or an instant booking"""  
    color: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('color') }})
    r"""The hexadecimal color value of the event type's scheduling page"""  
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the event type was created (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    custom_questions: list[shared_eventtypecustomquestion.EventTypeCustomQuestion] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('custom_questions') }})  
    deleted_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('deleted_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the event type was deleted (e.g. \\"2020-01-02T03:04:05.678123Z\\"). Since event types can be deleted but their scheduled events remain it's useful to fetch a deleted event type when you still require event type data for a scheduled event."""  
    description_html: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description_html') }})
    r"""The event type's description (formatted with HTML)"""  
    description_plain: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description_plain') }})
    r"""The event type's description (in non formatted text)"""  
    duration: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('duration') }})
    r"""The length of sessions booked with this event type"""  
    internal_note: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('internal_note') }})
    r"""Contents of a note that may be associated with the event type"""  
    kind: EventTypeKindEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('kind') }})
    r"""Indicates if the event type is \\"solo\\" (belongs to an individual user) or \\"group\\" """  
    kind_description: EventTypeKindDescriptionEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('kind_description') }})
    r"""A formatted description of the kind of event type."""  
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""The event type name (in human-readable format)"""  
    pooling_type: EventTypePoolingTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pooling_type') }})
    r"""Indicates if the event type is \\"round robin\\" (alternates between hosts) or \\"collective\\" (invitees pick a time when all participants are available) or \\"null\\" (the event type doesn’t consider the availability of a group participants)"""  
    profile: shared_profile.Profile = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('profile') }})
    r"""The publicly visible profile of a User or a Team that's associated with the Event Type (note: some Event Types don't have profiles)"""  
    scheduling_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('scheduling_url') }})
    r"""The URL of the user’s scheduling site where invitees book this event type"""  
    secret: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('secret') }})
    r"""Indicates if the event type is hidden on the owner's main scheduling page"""  
    slug: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('slug') }})
    r"""The portion of the event type's URL that identifies a specific web page (in a human-readable format)"""  
    type: EventTypeTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates if the event type is \\"AdhocEventType\\" (ad hoc event) or \\"StandardEventType\\" (standard event type)"""  
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updated_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the event type was last updated (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the event type"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class InboundCallTypeEnum(str, Enum):
    r"""Indicates that the invitee will call the event host"""
    INBOUND_CALL = 'inbound_call'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InboundCall:
    r"""Invitee will call meeting publisher at the specified phone number"""
    
    location: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location') }})
    r"""The phone number the invitee will use to call the event host (publisher)"""  
    type: InboundCallTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates that the invitee will call the event host"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import eventtypeavailabletime as shared_eventtypeavailabletime
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from typing import Optional


@dataclasses.dataclass
class GetEventTypeAvailableTimesRequest:
    
    end_time: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'end_time', 'style': 'form', 'explode': True }})
    r"""End time of the requested availability range."""  
    event_type: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'event_type', 'style': 'form', 'explode': True }})
    r"""The uri associated with the event type"""  
    start_time: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'start_time', 'style': 'form', 'explode': True }})
    r"""Start time of the requested availability range."""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetEventTypeAvailableTimesErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetEventTypeAvailableTimesErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[GetEventTypeAvailableTimesErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetEventTypeAvailableTimes200ApplicationJSON:
    r"""Service Response"""
    
    collection: list[shared_eventtypeavailabletime.EventTypeAvailableTime] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('collection') }})
    r"""The set of available times for the event type matching the criteria"""  
    

@dataclasses.dataclass
class GetEventTypeAvailableTimesResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[GetEventTypeAvailableTimesErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    get_event_type_available_times_200_application_json_object: Optional[GetEventTypeAvailableTimes200ApplicationJSON] = dataclasses.field(default=None)
    r"""OK"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional

class PostSchedulingLinksRequestBodyMaxEventCountEnum(str, Enum):
    r"""The max number of events that can be scheduled using this scheduling link."""
    ONE = '1'

class PostSchedulingLinksRequestBodyOwnerTypeEnum(str, Enum):
    r"""Resource type (currently, this is always EventType)"""
    EVENT_TYPE = 'EventType'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSchedulingLinksRequestBody:
    
    max_event_count: PostSchedulingLinksRequestBodyMaxEventCountEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('max_event_count') }})
    r"""The max number of events that can be scheduled using this scheduling link."""  
    owner: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('owner') }})
    r"""A link to the resource that owns this Scheduling Link (currently, this is always an Event Type)"""  
    owner_type: PostSchedulingLinksRequestBodyOwnerTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('owner_type') }})
    r"""Resource type (currently, this is always EventType)"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSchedulingLinksErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSchedulingLinksErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[PostSchedulingLinksErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    
class PostSchedulingLinks201ApplicationJSONResourceOwnerTypeEnum(str, Enum):
    r"""Resource type (currently, this is always EventType)"""
    EVENT_TYPE = 'EventType'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSchedulingLinks201ApplicationJSONResource:
    
    booking_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('booking_url') }})
    r"""Scheduling link url"""  
    owner: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('owner'), 'exclude': lambda f: f is None }})
    r"""A link to the resource that owns this Scheduling Link (currently, this is always an Event Type)"""  
    owner_type: Optional[PostSchedulingLinks201ApplicationJSONResourceOwnerTypeEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('owner_type'), 'exclude': lambda f: f is None }})
    r"""Resource type (currently, this is always EventType)"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostSchedulingLinks201ApplicationJSON:
    r"""Created"""
    
    resource: PostSchedulingLinks201ApplicationJSONResource = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('resource') }})  
    

@dataclasses.dataclass
class PostSchedulingLinksResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[PostSchedulingLinksErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    post_scheduling_links_201_application_json_object: Optional[PostSchedulingLinks201ApplicationJSON] = dataclasses.field(default=None)
    r"""Created"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from ..shared import submissionquestionandanswer as shared_submissionquestionandanswer
from ..shared import submissiontracking as shared_submissiontracking
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields
from typing import Any, Optional

class RoutingFormSubmissionSubmitterTypeEnum(str, Enum):
    r"""Type of the respondent resource that submitted the form and scheduled a meeting."""
    INVITEE = 'Invitee'
    NULL = 'null'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class RoutingFormSubmission:
    r"""Information about a Routing Form Submission."""
    
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the routing form was submitted."""  
    questions_and_answers: list[shared_submissionquestionandanswer.SubmissionQuestionAndAnswer] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('questions_and_answers') }})
    r"""All Routing Form Submission questions with answers."""  
    routing_form: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('routing_form') }})
    r"""The URI of the routing form that's associated with the submission."""  
    submitter: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('submitter') }})
    r"""The reference to the Invitee resource when routing form submission results in a scheduled meeting."""  
    submitter_type: RoutingFormSubmissionSubmitterTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('submitter_type') }})
    r"""Type of the respondent resource that submitted the form and scheduled a meeting."""  
    tracking: shared_submissiontracking.SubmissionTracking = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tracking') }})
    r"""The UTM and Salesforce tracking parameters associated with a Routing Form Submission."""  
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updated_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the routing form submission was last updated."""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the routing form submission."""  
    result: Optional[Any] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('result'), 'exclude': lambda f: f is None }})
    r"""The polymorphic base type for a Routing Form Submission result."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from ..shared import question as shared_question
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields

class RoutingFormStatusEnum(str, Enum):
    r"""Indicates if the form is in \\"draft\\" or \\"published\\" status."""
    DRAFT = 'draft'
    PUBLISHED = 'published'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class RoutingForm:
    r"""Information about a routing form."""
    
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the routing form was created."""  
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""The routing form name (in human-readable format)."""  
    organization: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('organization') }})
    r"""The URI of the organization that's associated with the routing form."""  
    questions: list[shared_question.Question] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('questions') }})
    r"""An ordered collection of Routing Form non-deleted questions."""  
    status: RoutingFormStatusEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    r"""Indicates if the form is in \\"draft\\" or \\"published\\" status."""  
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updated_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the routing form was last updated."""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the routing form."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from marshmallow import fields


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InviteeNoShow:
    r"""Information about an invitees no show."""
    
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the no show was created"""  
    invitee: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('invitee') }})
    r"""Canonical reference (unique identifier) for the associated Invitee"""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the no show"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from . import utils
from calendly.models import operations
from typing import Optional

class Webhooks:
    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version
        
    def create(self, request: operations.PostUsersUUIDWebhooksRequestBody) -> operations.PostUsersUUIDWebhooksResponse:
        r"""Create Webhook Subscription
        Create a Webhook Subscription for an Organization or User.
        
        * The `organization` subscription scope triggers the webhook for all subscribed events within the organization.
        * The `user` subscription scope only triggers the webhook for subscribed events that belong to the specific user.
        
        | Event | Allowed Subscription Scopes |
        | ----- | --------------------------- |
        | <pre>invitee.created</pre> | `organization` `user` |
        | <pre>invitee.canceled</pre> | `organization` `user` |
        | <pre>routing_form_submission.created</pre> | `organization` <br /> <small>Create separate Webhook Subscriptions for events with different subscription scopes.</small> |
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/webhook_subscriptions'
        
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        
        client = self._security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.PostUsersUUIDWebhooksResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 201:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostUsersUUIDWebhooks201ApplicationJSON])
                res.post_users_uuid_webhooks_201_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 409]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostUsersUUIDWebhooksErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostUsersUUIDWebhooks403ApplicationJSON])
                res.post_users_uuid_webhooks_403_application_json_object = out

        return res

    def delete(self, request: operations.DeleteUsersUserUUIDWebhooksWebhookUUIDRequest) -> operations.DeleteUsersUserUUIDWebhooksWebhookUUIDResponse:
        r"""Delete Webhook Subscription
        Delete a Webhook Subscription.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.DeleteUsersUserUUIDWebhooksWebhookUUIDRequest, base_url, '/webhook_subscriptions/{webhook_uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('DELETE', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.DeleteUsersUserUUIDWebhooksWebhookUUIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 204:
            pass
        elif http_res.status_code in [401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.DeleteUsersUserUUIDWebhooksWebhookUUIDErrorResponse])
                res.error_response = out

        return res

    def get(self, request: operations.GetUsersUserUUIDWebhooksWebhookUUIDRequest) -> operations.GetUsersUserUUIDWebhooksWebhookUUIDResponse:
        r"""Get Webhook Subscription
        Get a specified Webhook Subscription.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetUsersUserUUIDWebhooksWebhookUUIDRequest, base_url, '/webhook_subscriptions/{webhook_uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetUsersUserUUIDWebhooksWebhookUUIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUsersUserUUIDWebhooksWebhookUUID200ApplicationJSON])
                res.get_users_user_uuid_webhooks_webhook_uuid_200_application_json_object = out
        elif http_res.status_code in [401, 403, 404]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUsersUserUUIDWebhooksWebhookUUIDErrorResponse])
                res.error_response = out

        return res

    def list(self, request: operations.ListWebhooksRequest) -> operations.ListWebhooksResponse:
        r"""List Webhook Subscriptions
        Get a list of Webhook Subscriptions for a specified Organization or User.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/webhook_subscriptions'
        
        query_params = utils.get_query_params(operations.ListWebhooksRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.ListWebhooksResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListWebhooks200ApplicationJSON])
                res.list_webhooks_200_application_json_object = out
        elif http_res.status_code in [400, 401, 404]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListWebhooksErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListWebhooks403ApplicationJSON])
                res.list_webhooks_403_application_json_object = out

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ..shared import availabilityrule as shared_availabilityrule
from calendly import utils
from dataclasses_json import Undefined, dataclass_json


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class AvailabilitySchedule:
    r"""The availability schedule set by the user."""
    
    default: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('default') }})
    r"""This is the default Availability Schedule in use."""  
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""The name of this Availability Schedule."""  
    rules: list[shared_availabilityrule.AvailabilityRule] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('rules') }})
    r"""The rules of this Availability Schedule."""  
    timezone: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('timezone') }})
    r"""The timezone for which this Availability Schedule is originated in."""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""A URI reference to this Availability Schedule."""  
    user: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('user') }})
    r"""A URI reference to a User."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class GoogleConferenceStatusEnum(str, Enum):
    r"""Indicates the current status of the Google conference"""
    INITIATED = 'initiated'
    PROCESSING = 'processing'
    PUSHED = 'pushed'
    FAILED = 'failed'

class GoogleConferenceTypeEnum(str, Enum):
    r"""The event location is a Google Meet or Hangouts conference"""
    GOOGLE_CONFERENCE = 'google_conference'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GoogleConference:
    r"""Details about an Event that will take place using a Google Meet / Hangout conference"""
    
    join_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('join_url') }})
    r"""Google conference meeting url"""  
    status: GoogleConferenceStatusEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    r"""Indicates the current status of the Google conference"""  
    type: GoogleConferenceTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The event location is a Google Meet or Hangouts conference"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class QuestionTypeEnum(str, Enum):
    r"""Question type: name, text input, email, phone, textarea input, dropdown list or radio button list."""
    NAME = 'name'
    TEXT = 'text'
    EMAIL = 'email'
    PHONE = 'phone'
    TEXTAREA = 'textarea'
    SELECT = 'select'
    RADIOS = 'radios'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Question:
    r"""Routing form questions."""
    
    answer_choices: list[str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('answer_choices') }})
    r"""The respondent’s option(s) for \\"select\\" or \\"radios\\" types of questions."""  
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""Question name (in human-readable format)."""  
    required: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('required') }})
    r"""true if an answer to the question is required for respondents to submit the routing form; false if not required."""  
    type: QuestionTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Question type: name, text input, email, phone, textarea input, dropdown list or radio button list."""  
    uuid: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uuid') }})
    r"""Unique identifier for the routing form question."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class InviteeSpecifiedLocationTypeEnum(str, Enum):
    r"""The event location selected by the invitee"""
    ASK_INVITEE = 'ask_invitee'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InviteeSpecifiedLocation:
    r"""Information about an event location that’s specified by the invitee."""
    
    location: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location') }})
    r"""The event location description provided by the invitee"""  
    type: InviteeSpecifiedLocationTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The event location selected by the invitee"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class InPersonMeetingTypeEnum(str, Enum):
    r"""Indicates that the event will be an in-person meeting."""
    PHYSICAL = 'physical'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InPersonMeeting:
    r"""Information about the physical (in-person) event location"""
    
    location: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location') }})
    r"""The physical location specified by the event host (publisher)"""  
    type: InPersonMeetingTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates that the event will be an in-person meeting."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields
from typing import Optional

class OrganizationInvitationStatusEnum(str, Enum):
    r"""The status of the invitation (\\"pending\\", \\"accepted\\", or \\"declined\\")"""
    PENDING = 'pending'
    ACCEPTED = 'accepted'
    DECLINED = 'declined'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class OrganizationInvitation:
    r"""Organization Invitation object"""
    
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the invitation was created (e.g. “2020-01-02T03:04:05.678123Z\\")"""  
    email: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('email') }})
    r"""The email address of the person who was invited to join the organization"""  
    last_sent_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('last_sent_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the invitation was last sent (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    organization: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('organization') }})
    r"""Canonical reference (unique identifier) for the organization"""  
    status: OrganizationInvitationStatusEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    r"""The status of the invitation (\\"pending\\", \\"accepted\\", or \\"declined\\")"""  
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updated_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the invitation was last updated (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the organization invitation"""  
    user: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('user'), 'exclude': lambda f: f is None }})
    r"""When the invitation is accepted, a reference to the user who accepted the invitation"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class CustomLocationTypeEnum(str, Enum):
    r"""The event location doesn't fall into a standard category defined by the event host (publisher)"""
    CUSTOM = 'custom'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CustomLocation:
    r"""Use this to describe an existing Calendly-supported event location."""
    
    location: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location') }})
    r"""The location description provided by the event host (publisher)"""  
    type: CustomLocationTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The event location doesn't fall into a standard category defined by the event host (publisher)"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import organizationinvitation as shared_organizationinvitation
from ..shared import pagination as shared_pagination
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional

class GetOrganizationsUUIDInvitationsStatusEnum(str, Enum):
    r"""Indicates if the results should be filtered by status  (\\"pending\\", \\"accepted\\", or \\"declined\\")"""
    PENDING = 'pending'
    ACCEPTED = 'accepted'
    DECLINED = 'declined'


@dataclasses.dataclass
class GetOrganizationsUUIDInvitationsRequest:
    
    uuid: str = dataclasses.field(metadata={'path_param': { 'field_name': 'uuid', 'style': 'simple', 'explode': False }})
    r"""The organization's unique identifier"""  
    count: Optional[float] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'count', 'style': 'form', 'explode': True }})
    r"""The number of rows to return"""  
    email: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'email', 'style': 'form', 'explode': True }})
    r"""Indicates if the results should be filtered by email address"""  
    page_token: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'page_token', 'style': 'form', 'explode': True }})
    r"""The token to pass to get the next or previous portion of the collection"""  
    sort: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'sort', 'style': 'form', 'explode': True }})
    r"""Order results by the field name and direction specified (ascending or descending). Returns multiple sets of results in a comma-separated list."""  
    status: Optional[GetOrganizationsUUIDInvitationsStatusEnum] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'status', 'style': 'form', 'explode': True }})
    r"""Indicates if the results should be filtered by status  (\\"pending\\", \\"accepted\\", or \\"declined\\")"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetOrganizationsUUIDInvitationsErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetOrganizationsUUIDInvitationsErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[GetOrganizationsUUIDInvitationsErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetOrganizationsUUIDInvitations200ApplicationJSON:
    r"""OK"""
    
    collection: list[shared_organizationinvitation.OrganizationInvitation] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('collection') }})  
    pagination: shared_pagination.Pagination = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pagination') }})  
    

@dataclasses.dataclass
class GetOrganizationsUUIDInvitationsResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[GetOrganizationsUUIDInvitationsErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    get_organizations_uuid_invitations_200_application_json_object: Optional[GetOrganizationsUUIDInvitations200ApplicationJSON] = dataclasses.field(default=None)
    r"""OK"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from . import utils
from .activity_log import ActivityLog
from .availability import Availability
from .data_compliance import DataCompliance
from .event_types import EventTypes
from .organizations import Organizations
from .routing_forms import RoutingForms
from .scheduled_events import ScheduledEvents
from .scheduling_links import SchedulingLinks
from .shares import Shares
from .users import Users
from .webhooks import Webhooks
from calendly.models import shared

SERVERS = [
    "https://api.calendly.com",
]
"""Contains the list of servers available to the SDK"""

class Calendly:
    r"""Calendly’s API is [REST](http://en.wikipedia.org/wiki/Representational_State_Transfer)-based and has predictable resource-oriented URLs. It uses **JSON** for request and response bodies and standard HTTP methods, authentication, and response codes.<br>
    
    ##### Authenticate with personal access tokens or OAuth 2.0
    
    To access Calendly data through the API, you can authenticate with **personal access tokens** or **OAuth 2.0**. To learn more about these authentication methods and when and how to use them, see [Getting Started with the Calendly API](https://developer.calendly.com/getting-started).
    """
    activity_log: ActivityLog
    availability: Availability
    data_compliance: DataCompliance
    event_types: EventTypes
    organizations: Organizations
    routing_forms: RoutingForms
    scheduled_events: ScheduledEvents
    scheduling_links: SchedulingLinks
    shares: Shares
    users: Users
    webhooks: Webhooks

    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str = SERVERS[0]
    _language: str = "python"
    _sdk_version: str = "0.0.2"
    _gen_version: str = "2.17.8"

    def __init__(self,
                 security: shared.Security = None,
                 server_url: str = None,
                 url_params: dict[str, str] = None,
                 client: requests_http.Session = None
                 ) -> None:
        """Instantiates the SDK configuring it with the provided parameters.
        
        :param security: The security details required for authentication
        :type security: shared.Security
        :param server_url: The server URL to use for all operations
        :type server_url: str
        :param url_params: Parameters to optionally template the server URL with
        :type url_params: dict[str, str]
        :param client: The requests.Session HTTP client to use for all operations
        :type client: requests_http.Session        
        """
        self._client = requests_http.Session()
        
        
        if server_url is not None:
            if url_params is not None:
                self._server_url = utils.template_url(server_url, url_params)
            else:
                self._server_url = server_url

        if client is not None:
            self._client = client
        
        self._security_client = utils.configure_security_client(self._client, security)
        

        self._init_sdks()
    
    def _init_sdks(self):
        self.activity_log = ActivityLog(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
        self.availability = Availability(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
        self.data_compliance = DataCompliance(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
        self.event_types = EventTypes(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
        self.organizations = Organizations(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
        self.routing_forms = RoutingForms(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
        self.scheduled_events = ScheduledEvents(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
        self.scheduling_links = SchedulingLinks(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
        self.shares = Shares(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
        self.users = Users(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
        self.webhooks = Webhooks(
            self._client,
            self._security_client,
            self._server_url,
            self._language,
            self._sdk_version,
            self._gen_version
        )
        
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from ..shared import cancellation as shared_cancellation
from ..shared import inviteequestionandanswer as shared_inviteequestionandanswer
from ..shared import inviteetracking as shared_inviteetracking
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InviteeNoShow1:
    r"""Provides data pertaining to the associated no show for the Invitee"""
    
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the no show was created"""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the no show"""  
    
class InviteePaymentCurrencyEnum(str, Enum):
    r"""The currency format that the payment is in."""
    AUD = 'AUD'
    CAD = 'CAD'
    EUR = 'EUR'
    GBP = 'GBP'
    USD = 'USD'

class InviteePaymentProviderEnum(str, Enum):
    r"""Payment provider"""
    STRIPE = 'stripe'
    PAYPAL = 'paypal'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InviteePayment:
    r"""Invitee payment"""
    
    amount: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('amount') }})
    r"""The amount of the payment"""  
    currency: InviteePaymentCurrencyEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('currency') }})
    r"""The currency format that the payment is in."""  
    external_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('external_id') }})
    r"""Unique identifier for the payment"""  
    provider: InviteePaymentProviderEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('provider') }})
    r"""Payment provider"""  
    successful: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('successful') }})
    r"""Indicates whether the payment was successfully processed"""  
    terms: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('terms') }})
    r"""Terms of the payment"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InviteeReconfirmation:
    r"""Assuming reconfirmation is enabled for the event type, when reconfirmation is requested this object is present with a `created_at` that reflects when the reconfirmation notification was sent. Once the invitee has reconfirmed the `confirmed_at` attribute will change from `null` to a timestamp that reflects when they took action."""
    
    confirmed_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('confirmed_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""When the Invitee confirmed their attendance."""  
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""When the reconfirmation was created."""  
    
class InviteeStatusEnum(str, Enum):
    r"""Indicates if the invitee is \\"active\\" or \\"canceled\\" """
    ACTIVE = 'active'
    CANCELED = 'canceled'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Invitee:
    r"""An individual who has been invited to meet with a Calendly member"""
    
    cancel_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('cancel_url') }})
    r"""Link to cancelling the event for the invitee"""  
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the event was created (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    email: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('email') }})
    r"""The invitee’s email address"""  
    event: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('event') }})
    r"""A reference to the event"""  
    first_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('first_name') }})
    r"""The first name of the invitee who booked the event when the event type is configured to use separate fields for first name and last name. Null when event type is configured to use a single field for name."""  
    last_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('last_name') }})
    r"""The last name of the invitee who booked the event when the event type is configured to use separate fields for first name and last name. Null when event type is configured to use a single field for name."""  
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""The invitee’s name (in human-readable format)"""  
    new_invitee: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('new_invitee') }})
    r"""Link to new invitee, after reschedule"""  
    no_show: InviteeNoShow1 = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('no_show') }})
    r"""Provides data pertaining to the associated no show for the Invitee"""  
    old_invitee: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('old_invitee') }})
    r"""Reference to old Invitee instance that got rescheduled"""  
    payment: InviteePayment = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('payment') }})
    r"""Invitee payment"""  
    questions_and_answers: list[shared_inviteequestionandanswer.InviteeQuestionAndAnswer] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('questions_and_answers') }})
    r"""A collection of the invitee's responses to questions on the event booking confirmation form"""  
    reconfirmation: InviteeReconfirmation = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('reconfirmation') }})
    r"""Assuming reconfirmation is enabled for the event type, when reconfirmation is requested this object is present with a `created_at` that reflects when the reconfirmation notification was sent. Once the invitee has reconfirmed the `confirmed_at` attribute will change from `null` to a timestamp that reflects when they took action."""  
    reschedule_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('reschedule_url') }})
    r"""Link to rescheduling the event for the invitee"""  
    rescheduled: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('rescheduled') }})
    r"""Indicates if this invitee has rescheduled. If `true`, a reference to the new Invitee instance is provided in the `new_invitee` field."""  
    routing_form_submission: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('routing_form_submission') }})
    r"""Reference to a routing form submission that redirected the invitee to a booking page."""  
    status: InviteeStatusEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    r"""Indicates if the invitee is \\"active\\" or \\"canceled\\" """  
    text_reminder_number: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('text_reminder_number') }})
    r"""The phone number to use when sending text (SMS) reminders"""  
    timezone: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('timezone') }})
    r"""Time zone to use when displaying time to the invitee"""  
    tracking: shared_inviteetracking.InviteeTracking = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tracking') }})
    r"""The UTM and Salesforce tracking parameters associated with an Invitee"""  
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updated_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the event was last updated (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the invitee"""  
    cancellation: Optional[shared_cancellation.Cancellation] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('cancellation'), 'exclude': lambda f: f is None }})
    r"""Provides data pertaining to the cancellation of the Event"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import errorresponse as shared_errorresponse
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional


@dataclasses.dataclass
class RevokeUsersOrganizationInvitationRequest:
    
    org_uuid: str = dataclasses.field(metadata={'path_param': { 'field_name': 'org_uuid', 'style': 'simple', 'explode': False }})
    r"""The organization’s unique identifier"""  
    uuid: str = dataclasses.field(metadata={'path_param': { 'field_name': 'uuid', 'style': 'simple', 'explode': False }})
    r"""The organization invitation's unique identifier"""  
    
class RevokeUsersOrganizationInvitation403ApplicationJSONMessageEnum(str, Enum):
    YOU_CANNOT_PERFORM_THIS_ACTION_FOR_AN_ORGANIZATION_WITH_SCIM_ENABLED_ = 'You cannot perform this action for an organization with SCIM enabled.'
    YOU_DO_NOT_HAVE_PERMISSION = 'You do not have permission'
    YOU_DO_NOT_HAVE_PERMISSION_TO_ACCESS_THIS_RESOURCE_ = 'You do not have permission to access this resource.'

class RevokeUsersOrganizationInvitation403ApplicationJSONTitleEnum(str, Enum):
    PERMISSION_DENIED = 'Permission Denied'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class RevokeUsersOrganizationInvitation403ApplicationJSON:
    r"""Permission Denied"""
    
    message: Optional[RevokeUsersOrganizationInvitation403ApplicationJSONMessageEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message'), 'exclude': lambda f: f is None }})  
    title: Optional[RevokeUsersOrganizationInvitation403ApplicationJSONTitleEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class RevokeUsersOrganizationInvitationErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class RevokeUsersOrganizationInvitationErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[RevokeUsersOrganizationInvitationErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclasses.dataclass
class RevokeUsersOrganizationInvitationResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response1: Optional[RevokeUsersOrganizationInvitationErrorResponse] = dataclasses.field(default=None)
    r"""Cannot authenticate caller"""  
    error_response: Optional[shared_errorresponse.ErrorResponse] = dataclasses.field(default=None)
    r"""Bad Request"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    revoke_users_organization_invitation_403_application_json_object: Optional[RevokeUsersOrganizationInvitation403ApplicationJSON] = dataclasses.field(default=None)
    r"""Permission Denied"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from . import utils
from calendly.models import operations
from typing import Optional

class RoutingForms:
    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version
        
    def get_submissions(self, request: operations.GetRoutingFormSubmissionsRequest) -> operations.GetRoutingFormSubmissionsResponse:
        r"""List Routing Form Submissions
        Get a list of Routing Form Submissions for a specified Routing Form.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/routing_form_submissions'
        
        query_params = utils.get_query_params(operations.GetRoutingFormSubmissionsRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetRoutingFormSubmissionsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetRoutingFormSubmissions200ApplicationJSON])
                res.get_routing_form_submissions_200_application_json_object = out
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetRoutingFormSubmissionsErrorResponse])
                res.error_response = out

        return res

    def get_submissions_by_uuid(self, request: operations.GetRoutingFormSubmissionsUUIDRequest) -> operations.GetRoutingFormSubmissionsUUIDResponse:
        r"""Get Routing Form Submission
        Get a specified Routing Form Submission.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetRoutingFormSubmissionsUUIDRequest, base_url, '/routing_form_submissions/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetRoutingFormSubmissionsUUIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetRoutingFormSubmissionsUUID200ApplicationJSON])
                res.get_routing_form_submissions_uuid_200_application_json_object = out
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetRoutingFormSubmissionsUUIDErrorResponse])
                res.error_response = out

        return res

    def get_by_uuid(self, request: operations.GetRoutingFormsUUIDRequest) -> operations.GetRoutingFormsUUIDResponse:
        r"""Get Routing Form
        Get a specified Routing Form.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetRoutingFormsUUIDRequest, base_url, '/routing_forms/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetRoutingFormsUUIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetRoutingFormsUUID200ApplicationJSON])
                res.get_routing_forms_uuid_200_application_json_object = out
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetRoutingFormsUUIDErrorResponse])
                res.error_response = out

        return res

    def list(self, request: operations.ListRoutingFormsRequest) -> operations.ListRoutingFormsResponse:
        r"""List Routing Forms
        Get a list of Routing Forms for a specified Organization.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/routing_forms'
        
        query_params = utils.get_query_params(operations.ListRoutingFormsRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.ListRoutingFormsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListRoutingForms200ApplicationJSON])
                res.list_routing_forms_200_application_json_object = out
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListRoutingFormsErrorResponse])
                res.error_response = out

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import event as shared_event
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional


@dataclasses.dataclass
class GetScheduledEventsUUIDRequest:
    
    uuid: str = dataclasses.field(metadata={'path_param': { 'field_name': 'uuid', 'style': 'simple', 'explode': False }})
    r"""The event's unique identifier"""  
    
class GetScheduledEventsUUID403ApplicationJSONMessageEnum(str, Enum):
    YOU_ARE_NOT_ALLOWED_TO_VIEW_THIS_EVENT = 'You are not allowed to view this event'

class GetScheduledEventsUUID403ApplicationJSONTitleEnum(str, Enum):
    PERMISSION_DENIED = 'Permission Denied'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetScheduledEventsUUID403ApplicationJSON:
    r"""Permission Denied"""
    
    message: Optional[GetScheduledEventsUUID403ApplicationJSONMessageEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message'), 'exclude': lambda f: f is None }})  
    title: Optional[GetScheduledEventsUUID403ApplicationJSONTitleEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetScheduledEventsUUIDErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetScheduledEventsUUIDErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[GetScheduledEventsUUIDErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetScheduledEventsUUID200ApplicationJSON:
    r"""OK"""
    
    resource: shared_event.Event = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('resource') }})
    r"""Information about a scheduled meeting"""  
    

@dataclasses.dataclass
class GetScheduledEventsUUIDResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[GetScheduledEventsUUIDErrorResponse] = dataclasses.field(default=None)
    r"""Cannot authenticate caller"""  
    get_scheduled_events_uuid_200_application_json_object: Optional[GetScheduledEventsUUID200ApplicationJSON] = dataclasses.field(default=None)
    r"""OK"""  
    get_scheduled_events_uuid_403_application_json_object: Optional[GetScheduledEventsUUID403ApplicationJSON] = dataclasses.field(default=None)
    r"""Permission Denied"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import date
from enum import Enum
from marshmallow import fields
from typing import Optional

class ShareSchedulingLinksOwnerTypeEnum(str, Enum):
    r"""Resource type (currently, this is always EventType)"""
    EVENT_TYPE = 'EventType'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ShareSchedulingLinks:
    
    booking_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('booking_url') }})
    r"""Scheduling link url"""  
    owner: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('owner'), 'exclude': lambda f: f is None }})
    r"""A link to the resource that owns this Scheduling Link (currently, this is always an Event Type)"""  
    owner_type: Optional[ShareSchedulingLinksOwnerTypeEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('owner_type'), 'exclude': lambda f: f is None }})
    r"""Resource type (currently, this is always EventType)"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ShareShareOverrideAvailabilityRuleRulesIntervals:
    
    from_: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from'), 'exclude': lambda f: f is None }})
    r"""Format: `\\"hh:mm\\"`"""  
    to: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('to'), 'exclude': lambda f: f is None }})
    r"""Format: `\\"hh:mm\\"`"""  
    
class ShareShareOverrideAvailabilityRuleRulesTypeEnum(str, Enum):
    WDAY = 'wday'
    DATE = 'date'

class ShareShareOverrideAvailabilityRuleRulesWdayEnum(str, Enum):
    SUNDAY = 'sunday'
    MONDAY = 'monday'
    TUESDAY = 'tuesday'
    WEDNESDAY = 'wednesday'
    THURSDAY = 'thursday'
    FRIDAY = 'friday'
    SATURDAY = 'saturday'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ShareShareOverrideAvailabilityRuleRules:
    
    type: ShareShareOverrideAvailabilityRuleRulesTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})  
    date_: Optional[date] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('date'), 'encoder': utils.dateisoformat(True), 'decoder': utils.datefromisoformat, 'mm_field': fields.DateTime(format='iso'), 'exclude': lambda f: f is None }})
    r"""Format: `YYYY-MM-DD`"""  
    intervals: Optional[list[ShareShareOverrideAvailabilityRuleRulesIntervals]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('intervals'), 'exclude': lambda f: f is None }})  
    wday: Optional[ShareShareOverrideAvailabilityRuleRulesWdayEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('wday'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ShareShareOverrideAvailabilityRule:
    
    rules: list[ShareShareOverrideAvailabilityRuleRules] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('rules') }})  
    timezone: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('timezone') }})  
    
class ShareShareOverrideLocationConfigurationsKindEnum(str, Enum):
    PHYSICAL = 'physical'
    ASK_INVITEE = 'ask_invitee'
    CUSTOM = 'custom'
    OUTBOUND_CALL = 'outbound_call'
    INBOUND_CALL = 'inbound_call'
    GOOGLE_CONFERENCE = 'google_conference'
    GOTOMEETING_CONFERENCE = 'gotomeeting_conference'
    MICROSOFT_TEAMS_CONFERENCE = 'microsoft_teams_conference'
    ZOOM_CONFERENCE = 'zoom_conference'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ShareShareOverrideLocationConfigurations:
    
    additional_info: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('additional_info'), 'exclude': lambda f: f is None }})  
    kind: Optional[ShareShareOverrideLocationConfigurationsKindEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('kind'), 'exclude': lambda f: f is None }})  
    location: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location'), 'exclude': lambda f: f is None }})  
    phone_number: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('phone_number'), 'exclude': lambda f: f is None }})  
    position: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('position'), 'exclude': lambda f: f is None }})  
    
class ShareShareOverridePeriodTypeEnum(str, Enum):
    AVAILABLE_MOVING = 'available_moving'
    MOVING = 'moving'
    FIXED = 'fixed'
    UNLIMITED = 'unlimited'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ShareShareOverride:
    
    availability_rule: Optional[ShareShareOverrideAvailabilityRule] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('availability_rule'), 'exclude': lambda f: f is None }})  
    duration: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('duration'), 'exclude': lambda f: f is None }})  
    end_date: Optional[date] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('end_date'), 'encoder': utils.dateisoformat(True), 'decoder': utils.datefromisoformat, 'mm_field': fields.DateTime(format='iso'), 'exclude': lambda f: f is None }})
    r"""Format: `YYYY-MM-DD`"""  
    hide_location: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('hide_location'), 'exclude': lambda f: f is None }})  
    location_configurations: Optional[list[ShareShareOverrideLocationConfigurations]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location_configurations'), 'exclude': lambda f: f is None }})  
    max_booking_time: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('max_booking_time'), 'exclude': lambda f: f is None }})  
    name: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name'), 'exclude': lambda f: f is None }})  
    period_type: Optional[ShareShareOverridePeriodTypeEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('period_type'), 'exclude': lambda f: f is None }})  
    start_date: Optional[date] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('start_date'), 'encoder': utils.dateisoformat(True), 'decoder': utils.datefromisoformat, 'mm_field': fields.DateTime(format='iso'), 'exclude': lambda f: f is None }})
    r"""Format: `YYYY-MM-DD`"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Share:
    
    scheduling_links: list[ShareSchedulingLinks] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('scheduling_links') }})  
    share_override: ShareShareOverride = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('share_override') }})  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class AvailabilityRuleIntervals:
    
    from_: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from'), 'exclude': lambda f: f is None }})
    r"""Format: `\\"hh:mm\\"`"""  
    to: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('to'), 'exclude': lambda f: f is None }})
    r"""Format: `\\"hh:mm\\"`"""  
    
class AvailabilityRuleTypeEnum(str, Enum):
    r"""The type of this Availability Rule; can be \\"wday\\" or a specific \\"date\\"."""
    WDAY = 'wday'
    DATE = 'date'

class AvailabilityRuleWdayEnum(str, Enum):
    r"""The day of the week for which this Rule should be applied to."""
    SUNDAY = 'sunday'
    MONDAY = 'monday'
    TUESDAY = 'tuesday'
    WEDNESDAY = 'wednesday'
    THURSDAY = 'thursday'
    FRIDAY = 'friday'
    SATURDAY = 'saturday'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class AvailabilityRule:
    r"""The rules for an availability schedule."""
    
    intervals: list[AvailabilityRuleIntervals] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('intervals') }})
    r"""The intervals to be applied to this Rule. Each interval represents when booking a meeting is allowed. If the interval array is empty, then there is no booking availability for that day. Time is in 24h format (i.e. \\"17:30\\") and local to the timezone in the Availability Schedule."""  
    type: AvailabilityRuleTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The type of this Availability Rule; can be \\"wday\\" or a specific \\"date\\"."""  
    date_: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('date'), 'exclude': lambda f: f is None }})
    r"""A specific date in the future that this should be applied to (i.e. \\"2030-12-31\\")."""  
    wday: Optional[AvailabilityRuleWdayEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('wday'), 'exclude': lambda f: f is None }})
    r"""The day of the week for which this Rule should be applied to."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class ProfileTypeEnum(str, Enum):
    r"""Indicates if the profile belongs to a \\"user\\" (individual) or \\"team\\" """
    USER = 'User'
    TEAM = 'Team'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Profile:
    r"""The publicly visible profile of a User or a Team that's associated with the Event Type (note: some Event Types don't have profiles)"""
    
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""Human-readable name for the profile of the user that's associated with the event type"""  
    owner: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('owner') }})
    r"""The unique reference to the user associated with the profile"""  
    type: ProfileTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates if the profile belongs to a \\"user\\" (individual) or \\"team\\" """  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import scheduledeventsresponse as shared_scheduledeventsresponse
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional

class ListScheduledEventsStatusEnum(str, Enum):
    r"""Whether the scheduled event is `active` or `canceled`"""
    ACTIVE = 'active'
    CANCELED = 'canceled'


@dataclasses.dataclass
class ListScheduledEventsRequest:
    
    count: Optional[float] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'count', 'style': 'form', 'explode': True }})
    r"""The number of rows to return"""  
    invitee_email: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'invitee_email', 'style': 'form', 'explode': True }})
    r"""Return events that are scheduled with the invitee associated with this email address"""  
    max_start_time: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'max_start_time', 'style': 'form', 'explode': True }})
    r"""Include events with start times prior to this time (sample time format: \\"2020-01-02T03:04:05.678123Z\\"). This time should use the UTC timezone."""  
    min_start_time: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'min_start_time', 'style': 'form', 'explode': True }})
    r"""Include events with start times after this time (sample time format: \\"2020-01-02T03:04:05.678123Z\\"). This time should use the UTC timezone."""  
    organization: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'organization', 'style': 'form', 'explode': True }})
    r"""Return events that are scheduled with the organization associated with this URI"""  
    page_token: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'page_token', 'style': 'form', 'explode': True }})
    r"""The token to pass to get the next or previous portion of the collection"""  
    sort: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'sort', 'style': 'form', 'explode': True }})
    r"""Order results by the specified field and direction. Accepts comma-separated list of {field}:{direction} values.
    Supported fields are: start_time.
    Sort direction is specified as: asc, desc.
    """  
    status: Optional[ListScheduledEventsStatusEnum] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'status', 'style': 'form', 'explode': True }})
    r"""Whether the scheduled event is `active` or `canceled`"""  
    user: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'user', 'style': 'form', 'explode': True }})
    r"""Return events that are scheduled with the user associated with this URI"""  
    
class ListScheduledEvents403ApplicationJSONMessageEnum(str, Enum):
    YOU_DO_NOT_HAVE_PERMISSION_TO_ACCESS_THIS_RESOURCE_ = 'You do not have permission to access this resource.'
    PLEASE_ALSO_SPECIFY_ORGANIZATION_WHEN_REQUESTING_EVENTS_FOR_A_USER_WITHIN_YOUR_ORGANIZATION_ = 'Please also specify organization when requesting events for a user within your organization.'
    THIS_USER_IS_NOT_IN_YOUR_ORGANIZATION = 'This user is not in your organization'
    YOU_DO_NOT_HAVE_PERMISSION = 'You do not have permission'

class ListScheduledEvents403ApplicationJSONTitleEnum(str, Enum):
    PERMISSION_DENIED = 'Permission Denied'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListScheduledEvents403ApplicationJSON:
    r"""Permission Denied"""
    
    message: Optional[ListScheduledEvents403ApplicationJSONMessageEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message'), 'exclude': lambda f: f is None }})  
    title: Optional[ListScheduledEvents403ApplicationJSONTitleEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListScheduledEventsErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListScheduledEventsErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[ListScheduledEventsErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclasses.dataclass
class ListScheduledEventsResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[ListScheduledEventsErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    list_scheduled_events_403_application_json_object: Optional[ListScheduledEvents403ApplicationJSON] = dataclasses.field(default=None)
    r"""Permission Denied"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    scheduled_events_response: Optional[shared_scheduledeventsresponse.ScheduledEventsResponse] = dataclasses.field(default=None)
    r"""OK"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from . import utils
from calendly.models import operations, shared
from typing import Optional

class Users:
    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version
        
    def get(self, request: operations.GetUserRequest) -> operations.GetUserResponse:
        r"""Get user
        Returns information about a specified User.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetUserRequest, base_url, '/users/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetUserResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUser200ApplicationJSON])
                res.get_user_200_application_json_object = out
        elif http_res.status_code in [401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserErrorResponse])
                res.error_response = out

        return res

    def get_memberships(self, request: operations.GetOrganizationsUUIDMembershipsRequest) -> operations.GetOrganizationsUUIDMembershipsResponse:
        r"""Get Organization Membership
        Returns information about a user's Organization Membership
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetOrganizationsUUIDMembershipsRequest, base_url, '/organization_memberships/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetOrganizationsUUIDMembershipsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetOrganizationsUUIDMemberships200ApplicationJSON])
                res.get_organizations_uuid_memberships_200_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetOrganizationsUUIDMembershipsErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ErrorResponse])
                res.error_response1 = out

        return res

    def me(self) -> operations.MeResponse:
        r"""Get current user
        Returns basic information about your user account.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/users/me'
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.MeResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.Me200ApplicationJSON])
                res.me_200_application_json_object = out
        elif http_res.status_code in [401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.MeErrorResponse])
                res.error_response = out

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UserBusyTimeEvent:
    
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""The uri associated with the calendly scheduled event"""  
    
class UserBusyTimeTypeEnum(str, Enum):
    r"""Indicates whether the scheduled event is internal or external"""
    CALENDLY = 'calendly'
    EXTERNAL = 'external'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class UserBusyTime:
    r"""An internal or external scheduled event for a given user"""
    
    end_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('end_time'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The end time of the scheduled event in UTC time"""  
    start_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('start_time'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The start time of the scheduled event in UTC time"""  
    type: UserBusyTimeTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates whether the scheduled event is internal or external"""  
    buffered_end_time: Optional[datetime] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('buffered_end_time'), 'encoder': utils.datetimeisoformat(True), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso'), 'exclude': lambda f: f is None }})
    r"""The end time of the calendly event, as calculated by any \\"after\\" buffer set by the user"""  
    buffered_start_time: Optional[datetime] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('buffered_start_time'), 'encoder': utils.datetimeisoformat(True), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso'), 'exclude': lambda f: f is None }})
    r"""The start time of the calendly event, as calculated by any \\"before\\" buffer set by the user"""  
    event: Optional[UserBusyTimeEvent] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('event'), 'exclude': lambda f: f is None }})  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InviteeQuestionAndAnswer:
    r"""A response to a question on a booking page form"""
    
    answer: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('answer') }})
    r"""The invitee's answer to the question"""  
    position: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('position') }})
    r"""The position of the question in relation to others on the booking form"""  
    question: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('question') }})
    r"""A question on the invitee's booking form"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from marshmallow import fields


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Guest:
    r"""An individual whom an invitee has invited to be a guest attendee to an event"""
    
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})  
    email: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('email') }})  
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updated_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import invitee as shared_invitee
from ..shared import pagination as shared_pagination
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional

class GetInviteesStatusEnum(str, Enum):
    r"""Indicates if the invitee \\"canceled\\" or still \\"active\\" """
    ACTIVE = 'active'
    CANCELED = 'canceled'


@dataclasses.dataclass
class GetInviteesRequest:
    
    uuid: str = dataclasses.field(metadata={'path_param': { 'field_name': 'uuid', 'style': 'simple', 'explode': False }})  
    count: Optional[float] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'count', 'style': 'form', 'explode': True }})
    r"""The number of rows to return"""  
    email: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'email', 'style': 'form', 'explode': True }})
    r"""Indicates if the results should be filtered by email address"""  
    page_token: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'page_token', 'style': 'form', 'explode': True }})
    r"""The token to pass to get the next or previous portion of the collection"""  
    sort: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'sort', 'style': 'form', 'explode': True }})
    r"""Order results by the **created_at** field and direction specified: ascending (\\"asc\\") or descending (\\"desc\\")"""  
    status: Optional[GetInviteesStatusEnum] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'status', 'style': 'form', 'explode': True }})
    r"""Indicates if the invitee \\"canceled\\" or still \\"active\\" """  
    
class GetInvitees403ApplicationJSONMessageEnum(str, Enum):
    YOU_ARE_NOT_ALLOWED_TO_VIEW_THIS_EVENT = 'You are not allowed to view this event'

class GetInvitees403ApplicationJSONTitleEnum(str, Enum):
    PERMISSION_DENIED = 'Permission Denied'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetInvitees403ApplicationJSON:
    r"""Permission Denied"""
    
    message: Optional[GetInvitees403ApplicationJSONMessageEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message'), 'exclude': lambda f: f is None }})  
    title: Optional[GetInvitees403ApplicationJSONTitleEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetInviteesErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetInviteesErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[GetInviteesErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetInvitees200ApplicationJSON:
    r"""Service response"""
    
    collection: list[shared_invitee.Invitee] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('collection') }})
    r"""The set of event invitees matching the criteria"""  
    pagination: shared_pagination.Pagination = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pagination') }})  
    

@dataclasses.dataclass
class GetInviteesResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[GetInviteesErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    get_invitees_200_application_json_object: Optional[GetInvitees200ApplicationJSON] = dataclasses.field(default=None)
    r"""OK"""  
    get_invitees_403_application_json_object: Optional[GetInvitees403ApplicationJSON] = dataclasses.field(default=None)
    r"""Permission Denied"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class SubmissionCustomMessageResultTypeEnum(str, Enum):
    r"""Indicates if the routing form submission resulted in a custom \\"thank you\\" message."""
    CUSTOM_MESSAGE = 'custom_message'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class SubmissionCustomMessageResultValue:
    r"""Contains an object with custom message headline and body."""
    
    body: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('body') }})
    r"""Body text displayed when answers don't match any routes."""  
    headline: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('headline') }})
    r"""Headline displayed when answers don't match any routes."""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class SubmissionCustomMessageResult:
    r"""Information about the custom message Routing Form Submission result."""
    
    type: SubmissionCustomMessageResultTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates if the routing form submission resulted in a custom \\"thank you\\" message."""  
    value: SubmissionCustomMessageResultValue = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('value') }})
    r"""Contains an object with custom message headline and body."""  
    